include("../src/TeXTable.jl");
using Test, .TeXTable

@testset "Alignment Tests" begin
    @test TeXTable.alignment("", 4) == "llll"
    @test TeXTable.alignment("c", 4) == "cccc"
    @test TeXTable.alignment("|c|", 3) == "|ccc|"
    @test TeXTable.alignment("|l|cr", 3) == "|l|cr"
end

@testset "Metadata Tests" begin
    @test TeXTable.metadata("Hi", "Fig:1") == "    \\caption{Hi\\label{Fig:1}}\n"
    @test TeXTable.metadata("", "Fig:2") == "    \\caption{\\label{Fig:2}}\n"
    @test TeXTable.metadata("Caption", "") == "    \\caption{Caption}\n"
end

@testset "Table Tests" begin
A = [1,2,3];

@test Table(A) == """
\\begin{table}[!h]
    \\centering
    \\begin{tabular}{l}
        \\hline
        1 \\\\
        2 \\\\
        3 \\\\
        \\hline
    \\end{tabular}
\\end{table}
"""

A = [1 2 3; 4 5 6; 7 8 9];

@test Table(A, caption = "Table of Ints", label = "Hi") == """
\\begin{table}[!h]
    \\centering
    \\begin{tabular}{lll}
        \\hline
        1 & 2 & 3 \\\\
        4 & 5 & 6 \\\\
        7 & 8 & 9 \\\\
        \\hline
    \\end{tabular}
    \\caption{Table of Ints\\label{Hi}}
\\end{table}
"""

B = [
    0.201595 -1.10374 -0.0999076 0.134969;
    -0.769797 0.103319 1.18272 0.653885;
    0.678021 1.36842 0.574247 1.45202;
    0.371321 -1.13066 0.150247 -1.39606;
];

@test Table(B, label = "Random Normals", align = "|l|cr|l") == """
\\begin{table}[!h]
    \\centering
    \\begin{tabular}{|l|cr|l}
        \\hline
        0.201595 & -1.10374 & -0.0999076 & 0.134969 \\\\
        -0.769797 & 0.103319 & 1.18272 & 0.653885 \\\\
        0.678021 & 1.36842 & 0.574247 & 1.45202 \\\\
        0.371321 & -1.13066 & 0.150247 & -1.39606 \\\\
        \\hline
    \\end{tabular}
    \\caption{\\label{Random Normals}}
\\end{table}
"""
end
